## dbt-bigquery 1.10.0-rc2 - June 24, 2025

### Features

- Add user agent in bigframes mode ([#1152](https://github.com/dbt-labs/dbt-adapters/issues/1152))

### Fixes

- Add create_notebook_client ([#977](https://github.com/dbt-labs/dbt-adapters/issues/977))
- Use execute wrapper instead of raw execute to add the query comment as query header ([#1090](https://github.com/dbt-labs/dbt-adapters/issues/1090))

### Under the Hood

- Issue drop statement before cloning ([#1077](https://github.com/dbt-labs/dbt-adapters/issues/1077))

### Dependencies

- update the lower bound for dbt-adapters version in dbt-bigquery to >=1.16 ([#1148](https://github.com/dbt-labs/dbt-adapters/pull/1148))
- add lower bound for google-auth in dbt-bigquery ([#1149](https://github.com/dbt-labs/dbt-adapters/pull/1149))

### Contributors
- [@Kayrnt](https://github.com/Kayrnt) ([#1090](https://github.com/dbt-labs/dbt-adapters/issues/1090))
- [@jeremyyeo](https://github.com/jeremyyeo) ([#1077](https://github.com/dbt-labs/dbt-adapters/issues/1077))
- [@jialuoo](https://github.com/jialuoo) ([#1152](https://github.com/dbt-labs/dbt-adapters/issues/1152), [#977](https://github.com/dbt-labs/dbt-adapters/issues/977))
